@@ -1,5 +1,6 @@
 package JavaScript::Packer;
 
+use 5.008;
 use warnings;
 use strict;
 use Carp;
@@ -8,7 +9,7 @@ use vars qw/$VERSION $COMMENT $DATA $WHITESPACE $CLEAN $BLOCK $WORD/;
 
 # =========================================================================== #
 
-$VERSION = '0.0101';
+$VERSION = '0.0102';
 
 $WORD = qr/([a-zA-Z0-9_]+)/;
 
@@ -324,7 +325,7 @@ sub _encode52 {
 	my $ret = $m > 25 ? chr( $m + 39 ) : chr( $m + 97 );
 	
 	if ( $c >= 52 ) {
-		$ret = _encode52( sprintf( "%d", ( $c / 52 ) ) ) . $ret;
+		$ret = _encode52( int( $c / 52 ) ) . $ret;
 	}
 	
 	return $ret;
@@ -338,7 +339,7 @@ sub _encode62 {
 	my $ret = $m > 35 ? chr( $m + 29 ) : $m > 9 ? chr( $m + 87 ) : $m;
 	
 	if ( $c >= 62 ) {
-		$ret = _encode62( sprintf( "%d", ( $c / 62 ) ) ) . $ret;
+		$ret = _encode62( int( $c / 62 ) ) . $ret;
 	}
 	
 	return $ret;
